@@ -47,7 +47,7 @@ ImageTags = {
         }
         // Hide #tag-start link and show tag-stop link
         jQuery('#tag-start-tagging').hide();
-        jQuery('#tag-stop-tagging').show();
+        jQuery('html, body').animate({scrollTop: jQuery('#tag-stop-tagging-box').show().offset().top-10}, 1000);
         // Find the form and bind its "onsubmit" event
         var formContainer = jQuery('#ajax-form');
         var form = formContainer.find('form');
@@ -86,7 +86,7 @@ ImageTags = {
         }
         // Show / Hide Start / Stop links
         jQuery('#tag-start-tagging').show();
-        jQuery('#tag-stop-tagging').hide();
+        jQuery('#tag-stop-tagging-box').fadeOut();
         // Remove class and click event handler
         jQuery('.tag-image-wrapper').removeClass('tag-tagging').unbind('click', ImageTags.onWrapperClick);
         // Destroy draggable objects
@@ -127,21 +127,26 @@ ImageTags = {
     turnRemovable: function(collection) {
         /* Turn collection into removable (i.e. bind click event)
          */
-        collection.click(ImageTags.onRemoveLinkClick);
+        //collection.click(ImageTags.onRemoveLinkClick);
+        collection.live('click', ImageTags.onRemoveLinkClick);
     },
     
     createActionLinks: function(collection) {
         var url = ImageTags.contextUrl();
         collection.each(function(idx, el) {
             var safeId = el.id.replace('image-tag-link-plain-', '');
-            var id = safeId.replace('-', '.');
-            var buffer = [];
-            buffer.push(' <span class="tag-actions">(');
-            buffer.push('<a class="tag-remove" href="' + url + '?form.widgets.remove:list=' + id + '&ajax:int=1">' + ImageTagsLabels.removeLinkText + '</a>');
-            buffer.push(' | ');
-            buffer.push('<a class="tag-edit" id="image-tag-edit-' + safeId + '" href="' + url + '?id=' + id + '">' + ImageTagsLabels.editLinkText + '</a>');
-            buffer.push(')</span>');
-            jQuery(el).after(buffer.join('\n'));
+            // If editLink exists, we don't need to create it again
+            var editLink = jQuery('#image-tag-edit-' + safeId);
+            if(editLink.length===0) {
+                var id = safeId.replace('-', '.');
+                var buffer = [];
+                buffer.push(' <span class="tag-actions">(');
+                buffer.push('<a class="tag-remove" href="' + url + '?form.widgets.remove:list=' + id + '&ajax:int=1">' + ImageTagsLabels.removeLinkText + '</a>');
+                buffer.push(' | ');
+                buffer.push('<a class="tag-edit" id="image-tag-edit-' + safeId + '" href="' + url + '?id=' + id + '">' + ImageTagsLabels.editLinkText + '</a>');
+                buffer.push(')</span>');
+                jQuery(el).after(buffer.join('\n'));            
+            }
         });
     },
 
@@ -408,7 +413,7 @@ ImageTags = {
         ImageTags.preventRealLink(jQuery('#image-tag-link-plain-' + safeId));
         ImageTags.createActionLinks(jQuery('#image-tag-link-plain-' + safeId));
         ImageTags.turnEditable(jQuery('#image-tag-plain-' + safeId + ' .tag-edit'));
-        ImageTags.turnRemovable(jQuery('#image-tag-plain-' + safeId + ' .tag-remove'));
+        //ImageTags.turnRemovable(jQuery('#image-tag-plain-' + safeId + ' .tag-remove'));
 
     },
     
@@ -456,16 +461,21 @@ ImageTags = {
          * into more fancy radio-buttons to show embed options
          */
         var code = jQuery('.tag-embed-code').removeClass('tag-embed-code').addClass('tag-embed-code-dyn');
+        var dd = code.find('dd');
         var labels = code.find('label').hide();
         var inputs = code.find('input').hide();
         var brs = code.find('br').remove();
         labels.each( function(idx, val) {
             var text = jQuery(val).text();
-            code.find('dd').prepend('<label for="tag-embed-label-' + text + '"><input type="radio" class="radio" name="tag-embed-choice" id="tag-embed-label-' + text + '" value="' + text + '"/>' + text + '</label>');
+            dd.prepend('<label for="tag-embed-label-' + text + '"><input type="radio" class="radio" name="tag-embed-choice" id="tag-embed-label-' + text + '" value="' + text + '"/>' + text + '</label>');
         });
+        // Create a textarea to display embed code
+        dd.append('<textarea id="tag-embed-textarea"></textarea>').find('#tag-embed-textarea').click(function(event) {
+            event.target.select();
+        });
+        // When clicking radio buttons, replace textarea value with matching hidden input fields
         code.find('input[type=radio]').click(function(event) {
-            code.find('.tag-embed-code-selected').hide();
-            code.find('#' + event.target.id.replace('-label-', '-code-')).show().addClass('tag-embed-code-selected').select();
+            jQuery('#tag-embed-textarea').attr('value', code.find('#' + event.target.id.replace('-label-', '-code-')).first().attr('value')).select();
         }).first().click();
 
     }
